# CodaLab Worksheets

[![Build Status](https://github.com/codalab/codalab-worksheets/workflows/CI/badge.svg)](https://github.com/codalab/codalab-worksheets/actions)
[![Downloads](https://pepy.tech/badge/codalab)](https://pepy.tech/project/codalab)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![PyPI version](https://badge.fury.io/py/codalab.svg)](https://badge.fury.io/py/codalab)

* [Official CodaLab Worksheets Instance](https://worksheets.codalab.org/)
* [CodaLab Worksheets Documentation](https://codalab-worksheets.readthedocs.io/en/latest/)
